Глоссарий
=========

.. glossary::
   :sorted:

   ID организации в Яндекс 360
      Числовой идентификатор организации в сервисе Яндекс 360. Его можно увидеть на странице `профиля организации <https://admin.yandex.ru/company-profile>`_.

   ID пользователя в Яндекс 360
      Числовой идентификатор пользователя в сервисе Яндекс 360.

   ID подразделения в Яндекс 360
      Числовой идентификатор подразделения в сервисе Яндекс 360.

   ID записи
      Числовой идентификатор записи
   
   Яндекс токен приложения
      Токен авторизации экземпляра приложения

      .. tip::
         Для более простой работы с токенами Яндекс OAuth, вы можете воспользоваться библиотекой
         `yandex_oauth <https://yandex-oauth.readthedocs.io/>`_

         .. code-block:: console

            $ pip install yandex_oauth

   Полное доменное имя
      Например example.com. Для кириллических доменов (например домен.рф) используйте кодировку Punycode.

      Используется в функциях:
         * :func:`yandex_360.dns.show_dns`
         * :func:`yandex_360.dns.edit_dns`
         * :func:`yandex_360.dns.delete_dns`
         * :func:`yandex_360.dns.add_dns`
